# Google Chrome/Chromium theming (requires 9.0.597 or newer)
style "chrome-gtk-frame"
{
    ChromeGtkFrame::frame-color = @bg_color
    ChromeGtkFrame::inactive-frame-color = @bg_color
    ChromeGtkFrame::frame-gradient-size = 16
    ChromeGtkFrame::frame-gradient-color = shade (1.08,@bg_color)
    ChromeGtkFrame::inactive-frame-gradient-color = shade (1.08,@bg_color)
    
    ChromeGtkFrame::incognito-frame-gradient-color = shade (1.08,@bg_color)
    ChromeGtkFrame::incognito-inactive-frame-gradient-color = shade (1.08,@bg_color)
    
    ChromeGtkFrame::scrollbar-slider-prelight-color = shade (1.10, @bg_color)
    ChromeGtkFrame::scrollbar-slider-normal-color = shade (1.02, @bg_color)
}

class "ChromeGtkFrame" style "chrome-gtk-frame"
widget_class "*Chrom*Button*" style "button"
