/* ###################################################################
 * Section common with Gnome Shell
 * ... contains a few cinnamon specific styles (rare occurences)
 * ###################################################################*/
stage {
}

.cinnamon-link {
    color: #0000ff;
    text-decoration: underline;
}

.cinnamon-link:hover {
    color: #0000e0;
}

StScrollBar {
    padding: 0px;
}

StScrollView.vfade {
    -st-vfade-offset: 4em;
}

StScrollView StScrollBar {
    min-width: 8px;
    min-height: 16px;
    padding: 2px;
}

StScrollBar StBin#trough {
    background-color: rgba(0, 0, 0, 0);
    border: 1px solid #555555;
    border-radius: 4px;
}

StScrollBar StButton#vhandle {
    background-color: rgba(90, 90, 90, 1);
    border: 1px solid rgba(90, 90, 90, 1);
    border-radius: 4px;
}

StScrollBar StButton#hhandle {
    background-color: rgba(90, 90, 90, 1);
    border: 1px solid rgba(90, 90, 90, 1);
    border-radius: 4px;
}

StScrollBar StButton#hhandle:hover,
StScrollBar StButton#vhandle:hover {
    background-color: rgba(100, 100, 100, 1);
}

#Tooltip {
    border: 1px solid rgba(212, 185, 67, 1.0);
    border-radius: 4px;
    padding: 2px 12px;
    background-gradient-end: rgba(251, 234, 159, 0.9);
    background-gradient-start: rgba(254, 245, 198, 0.9);
    background-gradient-direction: vertical;
    color: #000000;
    font-size: .85em;
    font-weight: normal;
    text-align: center;
}

/* ===================================================================
 * Shared button properties
 * ===================================================================*/
.notification-button,
.notification-icon-button,
.modal-dialog-button {
    color: white;
    border: 1px solid #8b8b8b;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(255, 255, 255, 0.2);
    background-gradient-end: rgba(255, 255, 255, 0);
    font-size: .85em;
    font-weight: normal;
    text-align: center;
}

.notification-button:hover,
.notification-icon-button:hover,
.modal-dialog-button:hover {
    background-gradient-start: rgba(255, 255, 255, 0.3);
    background-gradient-end: rgba(255, 255, 255, 0.1);
}

.notification-button:focus,
.notification-icon-button:focus,
.modal-dialog-button:focus {
    border: 1px solid rgba(35, 35, 35, 1);
}

.notification-button:active,
.notification-icon-button:active,
.modal-dialog-button:active,
.modal-dialog-button:pressed {
    background-gradient-start: rgba(255, 255, 255, 0);
    background-gradient-end: rgba(255, 255, 255, 0.2);
}

/* ===================================================================
 * PopupMenu (popupMenu.js)
 * ===================================================================*/
.menu {

    /*border: 1px solid rgba(120, 120, 120, 1);*/
    border: 1px solid rgba(50, 50, 50, 1);
    border-radius: 4px;
    background-color: rgba(63, 63, 63, 0.95);
    color: #fff;
    font-size: .95em;
    min-width: 100px;
}

.menu.top {
    border-radius: 0 0 4px 4px;
    border-top-width: 0;
}

.menu.bottom {
    border-radius: 4px 4px 0 0;
    border-bottom-width: 0;
}

.menu.left {
    border-radius: 0 4px 4px 0;
    border-left-width: 0;
}

.menu.right {
    border-radius: 4px 0 0 4px;
    border-right-width: 0;
}

.popup-submenu-menu-item:open {
    background-color: rgba(70, 70, 70, 0.7);
}

.popup-sub-menu {
    background-gradient-start: rgba(70, 70, 70, 0.7);
    background-gradient-end: rgba(70, 70, 70, 0.0);
    background-gradient-direction: vertical;
}

.popup-sub-menu .popup-menu-item:ltr {
    padding-right: 1.75em;
}

.popup-sub-menu .popup-menu-item:rtl {
    padding-left: 1.75em;
}

.popup-sub-menu StScrollBar {
    padding: 4px;
}

.popup-sub-menu StScrollBar StBin#trough {
    border-width: 0px;
}

.popup-sub-menu StScrollBar StBin#vhandle {
    background-color: #4c4c4c;
    border-width: 0px;
}

.popup-combo-menu {
    background-color: rgba(0, 0, 0, 0.9);
    padding: 1em 0em;
    color: #ffffff;
    font-size: 1.05em;
    border: 1px solid #5f5f5f;
    border-radius: 9px;
}

/* The remaining popup-menu sizing is all done in ems, so that if you
 * override .popup-menu.font-size, everything else will scale with it.
 */
.popup-menu-content {
    padding: 1em 0em;
}

.popup-menu-item {
    padding: .4em 1.75em;
    spacing: 1em;
}

.popup-menu-item:active {
    background-color: rgba(80, 80, 80, 0.5);
}

.popup-menu-item:insensitive {
    color: #9f9f9f;
}

.popup-combobox-item {
    spacing: 1em;
}

.popup-separator-menu-item {
    -gradient-height: 1px;
    -gradient-start: rgba(90, 90, 90, 1);
    -gradient-end: rgba(90, 90, 90, 1);
    -margin-horizontal: 1.5em;
    height: 1em;
}

.popup-alternating-menu-item:alternate {
    font-weight: bold;
}

.popup-slider-menu-item {
    height: 1em;
    min-width: 15em;
    color: white;
    -slider-height: 0.3em;
    -slider-background-color: rgba(35, 35, 35, 1);
    -slider-border-color: rgba(35, 35, 35, 1);
    -slider-active-background-color: rgba(100, 100, 100, 1);
    -slider-active-border-color: rgba(100, 100, 100, 1);
    -slider-border-width: 1px;
    -slider-handle-radius: 0.5em;
}

.popup-device-menu-item {
    spacing: .5em;
}

.popup-inactive-menu-item {
    font-weight: normal;
    color: #999;
}

.popup-subtitle-menu-item {
    font-weight: bold;
}

.popup-menu-icon {
    icon-size: 1.14em;
}

/* Switches (to be used in menus) */
.toggle-switch {
    width: 64px;
    height: 22px;
}

.toggle-switch-us {
    background-image: url("toggle-off-us.svg");
}

.toggle-switch-us:checked {
    background-image: url("toggle-on-us.svg");
}

.toggle-switch-intl {
    background-image: url("toggle-off-intl.svg");
}

.toggle-switch-intl:checked {
    background-image: url("toggle-on-intl.svg");
}

.nm-menu-item-icons {
    spacing: .5em;
}

/* ===================================================================
 * Panel (panel.js)
 * ===================================================================*/
#panel {
    color: #ffffff;
    font-size: 1em;
    font-weight: normal;
    height: 27px;
    width: 32px;
}

#panel:highlight {
    background-color: #aa5555;
}

.panel-dummy {
    border: 1px solid rgba(120, 120, 120, 0.9);
    background-color: rgba(63, 63, 63, 0.7);
}

.panel-dummy:entered {
    border: 1px solid rgba(63, 63, 63, 0.9);
    background-color: rgba(120, 120, 120, 0.7);
}

#panelLeft,
#panelCenter {
    spacing: 4px;
}

#panelLeft:dnd {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(255, 0, 0, 0.05);
    background-gradient-end: rgba(255, 0, 0, 0.2);
}

#panelLeft.vertical:dnd {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(255, 0, 0, 0.05);
    background-gradient-end: rgba(255, 0, 0, 0.2);
}

#panelCenter:dnd {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(0, 255, 0, 0.05);
    background-gradient-end: rgba(0, 255, 0, 0.2);
}

#panelCenter.vertical:dnd {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(0, 255, 0, 0.05);
    background-gradient-end: rgba(0, 255, 0, 0.2);
}

#panelRight:dnd {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(0, 0, 255, 0.05);
    background-gradient-end: rgba(0, 0, 255, 0.2);
}

#panelRight.vertical:dnd {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(0, 0, 255, 0.05);
    background-gradient-end: rgba(0, 0, 255, 0.2);
}

#panelLeft:ltr {
    padding-right: 4px;
}

#panelLeft:rtl {
    padding-left: 4px;
}

#panelRight:ltr {
    padding-left: 0px;
    spacing: 0px;
}

#panelRight:rtl {
    padding-right: 0px;
    spacing: 0px;
}

#panelLeft.vertical:ltr {
    padding-right: 0px;
}

#panelLeft.vertical:rtl {
    padding-left: 0px;
}

.panel-top,
.panel-bottom {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(70, 70, 70, 0.9);
    background-gradient-end: rgba(50, 50, 50, 0.9);
    box-shadow: 0px 0px 2px 2px rgba(0, 0, 0, 0.5);
}

.panel-left,
.panel-right {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(70, 70, 70, 0.9);
    background-gradient-end: rgba(50, 50, 50, 0.9);
    box-shadow: 0px 0px 2px 2px rgba(0, 0, 0, 0.5);
}

.system-status-icon {
    padding-left: 0px;
    padding-right: 0px;
    spacing: 0px;
    margin: 0px;
}

.system-status-icon.warning {
    color: #e1da1a;
}

.system-status-icon.error {
    color: #d54444;
}

.popup-menu-item-dot {
}

.system-status-icon {
    icon-size: 1.14em;
}

/* ===================================================================
 * Overview (workspace.js)
 * ===================================================================*/
#overview {
    spacing: 12px;
}

.workspace-thumbnails {
    spacing: 14px;
}

.workspace-add-button {
    background-image: url("add-workspace.png");
    height: 200px;
    width: 35px;
    transition-duration: 300;
}

.workspace-add-button:hover {
    background-image: url("add-workspace-hover.png");
    transition-duration: 300;
}

.workspace-close-button {
    background-image: url("close-window.svg");
    height: 34px;
    width: 34px;
    -cinnamon-close-overlap: 20px;
}

.window-caption {
    color: white;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(80, 80, 80, .8);
    background-gradient-end: rgba(60, 60, 60, .8);
    border: 1px solid rgba(0, 0, 0, 0);
    box-shadow: inset 0px 1px 0px 0px rgba(100, 100, 100, 1);
    border-radius: 4px;
    font-size: .9em;
    padding: 6px 8px;
    spacing: 8px;
    -cinnamon-caption-spacing: 8px;
}

.window-caption:focus {
    background-gradient-start: rgba(90, 90, 90, .8);
    background-gradient-end: rgba(70, 70, 70, .8);
    border: 1px solid rgba(120, 120, 120, 1);
}

.window-border {
    border: 3px rgba(120, 120, 120, 1);
    border-radius: 4px;
    background-color: rgba(255,255,255,.05);
    /* Cover rounded corners and some bad adjustment gaps */
    box-shadow: 0 0 0 1px rgba(120, 120, 120, 1) inset;
}

.window-close {
    background-image: url("close-window.svg");
    height: 28px;
    width: 28px;
    -cinnamon-close-overlap: 13px;
}

.window-close:hover {
    background-image: url("close-window-hover.svg");
}

.window-close-area {
    background-image: url("trash-icon.png");
    background-color: rgba(60, 60, 60, 0.8);
    border: 4px solid rgba(128, 128, 128, 0.8);
    border-bottom-width: 0px;
    border-radius: 20px 20px 0px 0px;
    height: 120px;
    width: 400px;
}

.expo-background {
    background-gradient-start: #000;
    background-gradient-end: #AAA;
    background-gradient-direction: vertical
}

.workspace-overview-background-shade {
    background-color: rgba(0, 0, 0, 0.4);
}

.expo-workspace-thumbnail-frame {
    border: 1px, rgba(64, 64, 64, 0.9);
    background-color: rgba(64, 64, 64, 0.9);
}

.expo-workspace-thumbnail-frame#active {
    border: 2px, rgba(32, 32, 32, 0.9);
    background-color: rgba(32, 32, 32, 0.9);
}

.overview-empty-placeholder {
    color: #ffffff;
    font-size: 2em;
}

/* ===================================================================
* Desklets (desklet.js)
* ===================================================================*/
.desklet {
    color: #fff;
}

.desklet:highlight,
.desklet-with-borders:highlight,
.desklet-with-borders-and-header:highlight {
    background-color: #aa5555;
}

.desklet-with-borders {
    border: 2px solid #a5a5a5;
    background-color: rgba(80, 80, 80, 0.8);
    color: #fff;
    border-radius-bottomleft: 12px;
    border-radius-bottomright: 12px;
    border-radius-topleft: 12px;
    border-radius-topright: 12px;
}

.desklet-with-borders-and-header {
    border: 2px solid #a5a5a5;
    background-color: rgba(80, 80, 80, 0.8);
    color: #fff;
    border-top: 1px;
    border-radius-bottomleft: 12px;
    border-radius-bottomright: 12px;
}

.desklet-header {
    border-radius-topleft: 12px;
    border-radius-topright: 12px;
    font-size: 1.05em;
    border: 2px solid #a5a5a5;
    border-bottom: 0px;
    background-color: rgba(80, 80, 80, 0.8);
    color: #fff;
    padding: 6px;
}

.desklet-drag-placeholder {
    border: 2px solid #6daa00;
    background-color: rgba(109, 170, 0, 0.3);
}

/* ===================================================================
 * Clock Desklet (clock@cinnamon.org/desklet.js)
 * ===================================================================*/
.clock-desklet-label {
}

/* ===================================================================
 * Looking Glass (lookingGlass.js)
 * ===================================================================*/

/*
 * Controls the styling of the dialog shown when using the inspector
 * from looking glass
 */

#LookingGlassDialog {
    background-color: rgba(35, 35, 35, 0.8);
    spacing: 4px;
    padding: 4px;
    border: 1px solid rgba(100, 100, 100, 0.8);
    border-radius: 4px;
    color: #CCCCCC;
}

/* ===================================================================
 * Date applet (calendar@cinnamon.org/calendar.js)
 * ===================================================================*/

.calendar-main-box {
}

.calendar {
    spacing-rows: 0px;
    spacing-columns: 0px;
}

.calendar-events-main-box {
  margin-right: 10px;
  height: 300px;
  min-width: 350px;

  padding: 10px;
  border: 1px solid rgba(90, 90, 90, 1);
  border-radius: 4px;
  background-gradient-direction: vertical;
  background-gradient-start: rgba(80, 80, 80, 0.7);
  background-gradient-end: rgba(60, 60, 60, 0.7);  
}

.calendar-events-no-events-box {
}

.calendar-events-no-events-button {
    color: #cccccc;
    padding: 7px;
}

.calendar-events-no-events-button:hover:active {
}

.calendar-events-no-events-button:hover {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 1px 1px rgba(120, 120, 120, 1);
    border-radius: 4px;
}

.calendar-events-no-events-icon {
    color: #cccccc;
}

.calendar-events-no-events-label {
    font-weight: bold;
    text-align: center;
}

.calendar-events-date-label {
  padding: .1em .1em .5em .1em;
  font-weight: bold;
  text-align: center;
}

.calendar-events-main-box .separator {
    background: unset;
}

.calendar-events-event-container {
    padding:  0;
}

.calendar-event-button {
    margin: 7px;
}

.calendar-event-button:hover {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 1px 1px rgba(120, 120, 120, 1);
    border-radius: 4px;
}

.calendar-event-row-content {
    padding: 7px;
    margin: 2px 7px 2px 7px;
}

.calendar-event-time-past {
    color: rgba(255, 255, 255, 0.2);
    font-weight: bold;
    text-align: left;
    margin-bottom: .2em;
}
.calendar-event-time-present {
    color: #white;
    font-weight: bold;
    text-align: left;
    margin-bottom: .2em;
}

.calendar-event-time-present:all-day {
    color: rgba(0,255,0,0.6);
}

.calendar-event-time-future {
    color: rgba(255, 255, 255, 0.8);
    font-weight: bold;
    text-align: left;
    margin-bottom: .2em;
}

.calendar-event-summary {
    color: #white;
    text-align: left;
    width: 200px;
    padding-bottom: 2px;
}

.calendar-event-countdown {
    text-align: right;
    margin-bottom: .6em;
}

.calendar-event-countdown:soon {
      font-weight: bold;
}

.calendar-event-countdown:imminent {
      font-weight: bold;
      color: #d2aa1e;
}

.calendar-event-countdown:current {
      font-weight: bold;
    color: rgba(0,255,0,0.6);
}

.calendar-event-button:hover .calendar-event-time-past,
.calendar-event-button:hover .calendar-event-time-present,
.calendar-event-button:hover .calendar-event-time-future,
.calendar-event-button:hover .calendar-event-summary,
.calendar-event-button:hover .calendar-event-countdown,
.calendar-event-button:hover .calendar-event-countdown:soon,
.calendar-event-button:hover .calendar-event-countdown:imminent,
.calendar-event-button:hover .calendar-event-countdown:current {
}

.calendar-event-color-strip {
  width: 4px;
  border-width: 1px;
  border-radius: 4px 0 0 4px;
}


.calendar-month-label {
    color: #cccccc;
    font-size: 1em;
    padding-bottom: 8px;
    padding-top: 8px;
    font-weight: bold;
}

.calendar-change-month-back {
    width: 18px;
    height: 12px;
    background-image: url("calendar-arrow-left.svg");
    border-radius: 4px;
    border: 1px solid rgba(0, 0, 0, 0);
}

.calendar-change-month-back:rtl {
    background-image: url("calendar-arrow-right.svg");
}

.calendar-change-month-back:hover {
    background-color: rgba(80, 80, 80, 1);
    border: 1px solid rgba(120, 120, 120, 1);
}

.calendar-change-month-back:active {
    background-color: rgba(50, 50, 50, 1);
}

.calendar-change-month-forward {
    width: 18px;
    height: 12px;
    background-image: url("calendar-arrow-right.svg");
    border-radius: 4px;
    border: 1px solid rgba(0, 0, 0, 0);
}

.calendar-change-month-forward:rtl {
    background-image: url("calendar-arrow-left.svg");
}

.calendar-change-month-forward:hover {
    background-color: rgba(80, 80, 80, 1);
    border: 1px solid rgba(120, 120, 120, 1);
}

.calendar-change-month-forward:active {
    background-color: rgba(50, 50, 50, 1);
}

.calendar-today-home-button,
.calendar-today-home-button-enabled {
    padding: 7px;
}

.calendar-today-home-button-enabled:hover {
    padding: 7px;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 1px 1px rgba(120, 120, 120, 1);
    border-radius: 4px;
}

.calendar-today-day-label {
    color: #cccccc;
    font-size: 1.75em;
    font-weight: bold;
    text-align: center;
    padding-bottom: .1em;
}

.calendar-today-date-label {
    color: #cccccc;
    font-size: 1.1em;
    font-weight: bold;
    text-align: center;
}

.calendar-day-event-dot-box {
  margin-top: 1.7em;
  max-rows: 1;
}

.calendar-day-event-dot {
  margin: 1px;
  border-radius: 2px;
  width: 4px;
  height: 4px;
}

.calendar-day-base {
    font-size: 1em;
    text-align: center;
    width: 2.4em;
    height: 2.4em;
}

.calendar-day-base:hover {
    background-color: #777777;
    color: #fff;
}

.calendar-day-base:active {
}

.calendar-day-heading {
    color: #cccccc;
    padding-top: 1em;
}

.calendar-week-number {
    color: #cccccc;
    font-weight: bold;
    font-size: 0.85em;
}

/* Hack used in lieu of border-collapse - see calendar.js */
.calendar-day {
    border: 1px solid rgba(90, 90, 90, 1);
    color: #cccccc;
    border-top-width: 0;
    border-left-width: 0;
}

.calendar-day-top {
    border-top-width: 1px;
}

.calendar-day-left {
    border-left-width: 1px;
}

.calendar-work-day {
}

.calendar-nonwork-day {
    background-color: rgba(128, 128, 128, 0.2);
}

.calendar-today {
    text-shadow: black 0px 2px 2px;
    color: #ffffff;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(40, 40, 40, 1);
    background-gradient-end: rgba(60, 60, 60, 1);
    box-shadow: inset 0px 0px 0px 1px rgba(120, 120, 120, 1);
}

.calendar-today:selected {
    font-weight: bold;
}

.calendar-other-month-day {
    color: #888888;
}

.calendar-not-today:selected {
    background-color: #777777;
    color: #fff;
    font-weight: bold;
}

/* ===================================================================
 * Notifications (messageTray.js)
 * ===================================================================*/
#notification {
    font-size: .85em;
    border-radius: 10px 10px 10px 10px;
    border: 2px solid rgba(214, 214, 214, 0.5);
    background-gradient-direction: vertical;
    background-gradient-start: rgba(66, 66, 66, 0.9);
    background-gradient-end: rgba(55, 55, 55, 0.9);
    padding: 8px 8px 8px 8px;
    spacing-rows: 10px;
    spacing-columns: 10px;
    margin-from-right-edge-of-screen: 20px;
    width: 34em;
    color: white;
}

/* For the links inside notifications. These URLs are already underlined with Pango markup. */
#notification .url-highlighter {
    link-color: #0000ff;
}

#notification.multi-line-notification {
    padding-bottom: 8px;
    color: white;
}

/* We use row-span = 2 for the image cell, which prevents its height preferences to be
   taken into account during allocation, so its height ends up being limited by the height
   of the content in the other rows. To avoid showing a stretched image, we set the minimum
   height of the table to be ICON_SIZE + IMAGE_SIZE + spacing-rows = 24 + 125 + 10 = 159 */
.notification-with-image {
    min-height: 159px;
    color: white;
}

#notification-scrollview {
    max-height: 10em;
}

#notification-scrollview > .top-shadow,
#notification-scrollview > .bottom-shadow {
    height: 1em;
}

#notification-scrollview:ltr > StScrollBar {
    padding-left: 6px;
}

#notification-scrollview:rtl > StScrollBar {
    padding-right: 6px;
}

#notification-body {
    spacing: 5px;
}

#notification-actions {
    spacing: 10px;
}

.notification-button {
    border-radius: 5px;
    padding: 4px 8px 5px;
}

.notification-button:focus {
    padding: 3px 8px 4px;
}

.notification-icon-button {
    border-radius: 5px;
    padding: 5px;
}

.notification-icon-button:focus {
    padding: 4px;
}

.notification-icon-button > StIcon {
    icon-size: 36px;
}

#notification StEntry {
    padding: 4px;
    border-radius: 4px;
    color: #a8a8a8;
    selected-color: black;
    border: 1px solid rgba(245, 245, 245, 0.2);
    background-gradient-direction: vertical;
    background-gradient-start: rgb(200, 200, 200);
    background-gradient-end: white;
    transition-duration: 300;
    box-shadow: inset 0px 2px 4px rgba(0, 0, 0, 0.6);
    caret-color: #a8a8a8;
    caret-size: 1px;
}

#notification StEntry:focus {
    border: 1px solid #8b8b8b;
    color: #333333;
    background-gradient-direction: vertical;
    background-gradient-start: rgb(200, 200, 200);
    background-gradient-end: white;
    caret-color: #545454;
    selection-background-color: #808080;
}

/* ===================================================================
 * Alt Tab (appSwitcher/classicSwitcher.js)
 * ===================================================================*/
#altTabPopup {
    padding: 8px;
    spacing: 16px;
}

.switcher-list {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(70, 70, 70, 1);
    background-gradient-end: rgba(50, 50, 50, 1);
    border-radius: 8px;
    padding: 20px;
    font-size: .9em;
    color: white;
    box-shadow: 0px 0px 12px 6px rgba(0, 0, 0, 1);
}

.switcher-list-item-container {
    spacing: 8px;
}

.thumbnail-scroll-gradient-left {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(51, 51, 51, 1.0);
    background-gradient-end: rgba(51, 51, 51, 0);
    border-radius: 24px;
    border-radius-topright: 0px;
    border-radius-bottomright: 0px;
    width: 60px;
}

.thumbnail-scroll-gradient-right {
    background-gradient-direction: horizontal;
    background-gradient-start: rgba(51, 51, 51, 0);
    background-gradient-end: rgba(51, 51, 51, 1.0);
    border-radius: 24px;
    border-radius-topleft: 0px;
    border-radius-bottomleft: 0px;
    width: 60px;
}

.switcher-list .item-box {
    padding: 8px;
    border: 1px solid rgba(0, 0, 0, 0);
    border-radius: 8px;
}

.switcher-list .item-box:outlined {
    padding: 6px;
    border: 2px solid rgba(85, 85, 85, 1.0);
}

.switcher-list .item-box:selected {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 1);
    background-gradient-end: rgba(70, 70, 70, 1);
    border: 1px solid rgba(120, 120, 120, 1);
}

.switcher-list .thumbnail-box {
    padding: 2px;
    spacing: 4px;
}

.switcher-list .thumbnail {
    width: 256px;
}

.switcher-list .separator {
    width: 1px;
    background: rgba(255, 255, 255, 0.33);
}

.ripple-box {
    width: 104px;
    height: 104px;
    background-image: url("corner-ripple.png");
}

.ripple-box:rtl {
    background-image: url("corner-ripple.png");
}

.switcher-arrow {
    border-color: rgba(0, 0, 0, 0);
    color: #808080;
}

.switcher-arrow:highlighted {
    border-color: rgba(0, 0, 0, 0);
    color: white;
}

.switcher-preview-backdrop {
    background-color: rgba(25, 25, 25, 0.65);
}

/* ===================================================================
 * Modal dialogs (modalDialog.js)
 * ===================================================================*/
.modal-dialog {
    font-size: 1em;
    border-radius: 8px;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(70, 70, 70, 1);
    background-gradient-end: rgba(50, 50, 50, 1);
    color: #babdb6;
    box-shadow: 0px 0px 12px 6px rgba(0, 0, 0, 1);
    padding: 20px;
}

.modal-dialog-button-box {
    padding-top: 20px;
}

.modal-dialog-button {
    border-radius: 4px;
    font-size: 1em;
    color: white;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(80, 80, 80, 1);
    background-gradient-end: rgba(60, 60, 60, 1);
    border: 1px solid rgba(0, 0, 0, 0);
    box-shadow: inset 0px 1px 0px 0px rgba(100, 100, 100, 1);
    padding: 4px 32px 5px;
}

.modal-dialog-button:hover {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 1);
    background-gradient-end: rgba(70, 70, 70, 1);
    border: 1px solid rgba(120, 120, 120, 1);
}

.modal-dialog-button:active,
.modal-dialog-button:checked {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(60, 60, 60, 1);
    background-gradient-end: rgba(40, 40, 40, 1);
    box-shadow: inset 0px 1px 0px 0px rgba(35, 35, 35, 1);
}

.modal-dialog-button:disabled {
    color: rgb(60, 60, 60);
}

.modal-dialog-button:focus {
    padding: 3px 31px 4px;
}

.info-osd {
    font-size: 2.4em;
    border-radius: 20px;
    background-color: rgba(55, 55, 55, 0.9);
    border: 2px solid rgba(90, 90, 90, 1.0);
    color: #fff;
    padding-right: 20px;
    padding-left: 20px;
    padding-bottom: 20px;
    padding-top: 20px;
    text-align: center;
}

.osd-window {
    border-radius: 24px;
    background-color: rgba(55, 55, 55, 0.9);
    border: 2px solid rgba(90, 90, 90, 1.0);
    color: white;
    padding: 20px;
    spacing: 5px;
}

.osd-window .level {
    height: 0.7em;
    border-radius: 0.3em;
    background-color: rgba(190, 190, 190, 0.2);
}

.osd-window .level-bar {
    border-radius: 0.3em;
    background-color: white;
}

/* ===================================================================
 * Run dialog (runDialog.js)
 * ===================================================================*/
.run-dialog-label {
    font-size: .9em;
    color: white;
}

.run-dialog-error-label {
    font-size: .9em;
    color: white;
}

.run-dialog-error-box {
    padding-top: 15px;
    spacing: 5px;
}

.run-dialog-entry {
    font-size: 1.05em;
    font-weight: bold;
    width: 23em;
    color: white;
    selection-background-color: white;
    selected-color: black;
}

.run-dialog-completion-box {
    padding-left: 15px;
    font-size: 1em;
}

.run-dialog {
    border-radius: 8px;
    padding-right: 21px;
    padding-left: 21px;
    padding-bottom: 5px;
    padding-top: 15px;
}

.lightbox {
    background-color: rgba(0, 0, 0, 0.4);
}

/* =============================================================================
 * CinnamonMountOperation Dialogs (cinnamonMountOperation.js)
 * ============================================================================= */
.cinnamon-mount-operation-icon {
    icon-size: 48px;
}

.mount-password-reask {
    color: red;
}

.show-processes-dialog,
.mount-question-dialog {
    spacing: 24px;
}

.show-processes-dialog-subject,
.mount-question-dialog-subject {
    font-size: 1.2em;
    font-weight: bold;
    color: #666666;
    padding-top: 10px;
    padding-left: 17px;
    padding-bottom: 6px;
}

.show-processes-dialog-subject:rtl,
.mount-question-dialog-subject:rtl {
    padding-left: 0px;
    padding-right: 17px;
}

.show-processes-dialog-description,
.mount-question-dialog-description {
    font-size: 1em;
    color: white;
    padding-left: 17px;
    width: 28em;
}

.show-processes-dialog-description:rtl,
.mount-question-dialog-description:rtl {
    padding-right: 17px;
}

.show-processes-dialog-app-list {
    font-size: 1em;
    max-height: 200px;
    padding-top: 24px;
    padding-left: 49px;
    padding-right: 32px;
}

.show-processes-dialog-app-list:rtl {
    padding-right: 49px;
    padding-left: 32px;
}

.show-processes-dialog-app-list-item {
    color: rgba(200, 200, 200, 1);
}

.show-processes-dialog-app-list-item:hover {
    color: white;
}

.show-processes-dialog-app-list-item:ltr {
    padding-right: 1em;
}

.show-processes-dialog-app-list-item:rtl {
    padding-left: 1em;
}

.show-processes-dialog-app-list-item-icon:ltr {
    padding-right: 17px;
}

.show-processes-dialog-app-list-item-icon:rtl {
    padding-left: 17px;
}

.show-processes-dialog-app-list-item-name {
    font-size: 1em;
}

.network-dialog-secret-table {
    spacing-rows: 15px;
}

/* ===================================================================
 * Magnifier (magnifier.js)
 * ===================================================================*/
.magnifier-zoom-region {
    border: 2px solid rgba(128, 0, 0, 1);
}

.magnifier-zoom-region.full-screen {
    border-width: 0px;
}

/* ===================================================================
 * On screen keyboard (keyboard.js)
 * ===================================================================*/
#keyboard {
    background-color: rgba(55, 55, 55, 1);
    box-shadow: 0px 0px 2px 2px rgba(0, 0, 0, 0.5);
}

.keyboard-layout {
    spacing: 10px;
    padding: 10px;
}

.keyboard-row {
    spacing: 15px;
}

.keyboard-key {
    min-height: 30px;
    min-width: 30px;
    background-gradient-start: rgba(80, 80, 80, 1);
    background-gradient-end: rgba(60, 60, 60, 1);
    background-gradient-direction: vertical;
    box-shadow: inset 0px 1px 0px 0px rgba(100, 100, 100, 1);
    font-size: 1.4em;
    font-weight: bold;
    border-radius: 8px;
    border: 1px solid rgba(0, 0, 0, 0);
    color: white;
}

.keyboard-key:grayed {
    color: #808080;
    border-color: #808080;
}

.keyboard-key:checked,
.keyboard-key:hover {
    background-gradient-start: rgba(90, 90, 90, 1);
    background-gradient-end: rgba(70, 70, 70, 1);
    background-gradient-direction: vertical;
    border: 1px solid rgba(120, 120, 120, 1);
}

.keyboard-key:active {
    background-gradient-start: rgba(60, 60, 60, 1);
    background-gradient-end: rgba(40, 40, 40, 1);
    background-gradient-direction: vertical;
    box-shadow: inset 0px 1px 0px 0px rgba(35, 35, 35, 1);
}

.keyboard-subkeys {
    color: white;
    padding: 5px;
    -arrow-border-radius: 8px;
    -arrow-background-color: rgba(50, 50, 50, 1);
    -arrow-border-width: 1px;
    -arrow-border-color: rgba(90, 90, 90, 1);
    -arrow-base: 20px;
    -arrow-rise: 10px;
    -boxpointer-gap: 1px;
}

/* ###################################################################
 * Cinnamon Specific Section
 * ###################################################################*/

/* ===================================================================
 * Menu applet (menu@cinnamon.org/applet.js)
 * ===================================================================*/

.menu-favorites-box {
    padding: 10px;
    border: 1px solid rgba(90, 90, 90, 1);
    border-radius: 4px;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(80, 80, 80, 0.7);
    background-gradient-end: rgba(60, 60, 60, 0.7);
}

.menu-favorites-button {
    padding-top: 10px;
    padding-left: 10px;
    padding-right: 10px;
    padding-bottom: 10px;
    border: 1px solid rgba(0, 0, 0, 0);
    border-radius: 4px;
}

.menu-favorites-button:hover {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 1);
    background-gradient-end: rgba(70, 70, 70, 1);
    box-shadow: inset 0px 1px 0px 0px rgba(100, 100, 100, 1);
    border: 1px solid rgba(120, 120, 120, 1);
}

.menu-categories-box {
    padding-top: 10px;
    padding-left: 30px;
    padding-right: 30px;
    padding-bottom: 10px;
}

.menu-applications-outer-box {
    padding: 0px 10px;
}

.menu-applications-inner-box {
    margin-top: 10px;
    margin-left: 10px;
    margin-right: 10px;
    margin-bottom: 0px;
}

.menu-applications-scrollbox {
  padding: 0;
}

.menu-application-button {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    max-width: 10px;
}

.menu-application-button:highlighted {

    /* This style is used in menu application buttons for applications which were newly installed */
    font-weight: bold;
}

.menu-application-button-selected {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    color: white;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 1px 1px rgba(120, 120, 120, 1);
    border-radius: 4px;
}

.menu-application-button-selected:highlighted {

    /* This style is used in menu application buttons for applications which were newly installed */
    font-weight: bold;
}

.menu-application-button-label:ltr {
    padding-left: 5px;
}

.menu-application-button-label:rtl {
    padding-right: 5px;
}

.menu-category-button {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
}

.menu-category-button-greyed {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    color: rgba(100, 100, 100, 1);
    font-style: italic;
}

.menu-category-button-selected {
    padding-top: 7px;
    padding-left: 7px;
    padding-right: 7px;
    padding-bottom: 7px;
    color: white;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 1px 1px rgba(120, 120, 120, 1);
    border-radius: 4px;
}

.menu-category-button-label:ltr {
    padding-left: 5px;
}

.menu-category-button-label:rtl {
    padding-right: 5px;
}

/* Name and description of the currently hovered item in the menu
 * This appears on the bottom right hand corner of the menu*/
.menu-selected-app-box {
    padding-right: 30px;
    padding-left: 28px;
    text-align: right;
}

.menu-selected-app-title {
    font-weight: bold;
}

.menu-selected-app-description {
    max-width: 150px;
}

.menu-search-box {
    padding-left: 30px;
}

#menu-search-entry {
    padding: 4px 12px;
    border-radius: 4px;
    color: rgb(128, 128, 128);
    border: 1px solid rgba(245, 245, 245, 0.2);
    background-gradient-start: rgba(5, 5, 6, 0.1);
    background-gradient-end: rgba(254, 254, 254, 0.1);
    background-gradient-direction: vertical;
    selected-color: black;
    caret-color: rgb(128, 128, 128);
    caret-size: 1px;
    width: 250px;
    transition-duration: 300;
}

#menu-search-entry:focus,
#menu-search-entry:hover {
    background-gradient-start: rgb(200, 200, 200);
    background-gradient-end: white;
    background-gradient-direction: vertical;
    border: 1px solid rgba(120, 120, 120, 1);
    box-shadow: inset 0px 1px 2px 0px rgba(0, 0, 0, 0.5);
}

#menu-search-entry:hover {
    transition-duration: 300;
}

#menu-search-entry:focus {
    color: rgb(64, 64, 64);
    font-weight: bold;
    transition-duration: 0;
}

.menu-search-entry-icon {
    icon-size: 1em;
    color: #8d8f8a;
}

.menu-context-menu {
}

/* ===================================================================
 * Window list applet (window-list@cinnamon.org/applet.js)
 * ===================================================================*/
.window-list-box {
    spacing: 3px;
    padding-top: 1px;
}

.window-list-box.vertical {
    spacing: 4px;
    padding-left: 0;
    padding-right: 0;
    padding-top: 10px;
    padding-bottom: 10px;
}

.window-list-item-box {
    color: rgba(255, 255, 255, 1.0);
    background-gradient-direction: vertical;
    background-gradient-start: rgba(100, 100, 100, 0.5);
    background-gradient-end: rgba(50, 50, 50, 0.5);
    box-shadow: inset 0px 0px 0px 1px rgba(80, 80, 80, 0.5);
    border-radius: 4px 4px 0px 0px;
    padding: 1px;
    padding-left: 5px;
    padding-right: 5px;
    transition-duration: 100;
    spacing: 0.5em;
}

.window-list-item-box.top {
    border-radius: 0 0 4px 4px;
    padding-left: 5px;
    padding-right: 5px;
}

.window-list-item-box.left {
    border-radius: 0 4px 4px 0;
    padding-left: 0;
    padding-right: 2px;
}

.window-list-item-box.right {
    border-radius: 4px 0 0 4px;
    padding-left: 2px;
    padding-right: 0;
}

.window-list-item-box.top,
.window-list-item-box.bottom {
    padding: 0 0.5em;
}

.window-list-item-box:active,
.window-list-item-box:checked,
.window-list-item-box:focus {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(220, 220, 220, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 0px 1px rgba(100, 100, 100, 0.5);
}

.window-list-item-box:hover {
    box-shadow: inset 0px 0px 0px 1px rgba(120, 120, 120, 0.5);
}

.window-list-item-demands-attention {
    background-gradient-start: rgba(255, 52, 52, 0.5);
    background-gradient-end: rgba(255, 144, 144, 0.5);
}

.window-list-preview {
    border: 1px solid rgba(50, 50, 50, 1);
    border-radius: 4px;
    background-color: rgba(63, 63, 63, 0.95);
    color: #fff;
    font-size: .95em;
    padding: 6px 12px 12px 12px;
    spacing: 0.5em;
}

.window-list-item-box .progress {
    border-radius: 4px 4px 0 0;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(172, 205, 138, 0.5);
    background-gradient-end: rgba(172, 205, 138, 0.9);
}

.panel-top .window-list-item-box .progress {
    border-radius: 0 0 4px 4px;
}

.panel-left .window-list-item-box .progress {
    border-radius: 0 4px 4px 0;
}

.panel-right .window-list-item-box .progress {
    border-radius: 4px 0 0 4px;
}

/* ===================================================================
 * Grouped window list (grouped-window-list@cinnamon.org)
 * ===================================================================*/

.grouped-window-list-thumbnail-label {
    padding-left: 4px;
}
.grouped-window-list-number-label {
    z-index: 99;
    color: white;
}
.grouped-window-list-badge {
    border-radius: 256px;
    background-color: rgb(100, 100, 100);
    box-shadow: inset 0px 0px 0px 1px rgba(100, 100, 100, 0.5);
}
.grouped-window-list-button-label {
    padding-left: 4px;
}
.grouped-window-list-thumbnail-alert {
    background: rgba(255,52,52,0.3);
}

.grouped-window-list-item-box {
    color: rgba(255, 255, 255, 1.0);
    background-gradient-direction: vertical;
    background-gradient-start: rgba(100, 100, 100, 0);
    background-gradient-end: rgba(50, 50, 50, 0);
    box-shadow: inset 0px 0px 0px 1px rgba(80, 80, 80, 0);
    border-radius: 4px 4px 0px 0px;
    padding: 1px;
    padding-left: 5px;
    padding-right: 5px;
    transition-duration: 100;
    spacing: 0.5em;
}

.grouped-window-list-item-box.top {
    border-radius: 0 0 4px 4px;
    padding-left: 5px;
    padding-right: 5px;
}

.grouped-window-list-item-box.left {
    border-radius: 0 4px 4px 0;
    padding-left: 0;
    padding-right: 2px;
}

.grouped-window-list-item-box.right {
    border-radius: 4px 0 0 4px;
    padding-left: 2px;
    padding-right: 0;
}

.grouped-window-list-item-box.top,
.grouped-window-list-item-box.bottom {
    padding: 0 0.5em;
}

.grouped-window-list-item-box:checked,
.grouped-window-list-item-box:active:focus:hover,
.grouped-window-list-item-box:active:hover,
.grouped-window-list-item-box:focus:hover {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(220, 220, 220, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 0px 1px rgba(100, 100, 100, 0.9);
}

.grouped-window-list-item-box:focus,
.grouped-window-list-item-box:active:focus {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(220, 220, 220, 0.3);
    background-gradient-end: rgba(70, 70, 70, 0.3);
    box-shadow: inset 0px 0px 0px 1px rgba(100, 100, 100, 0.5);
}

.grouped-window-list-item-box:focus:hover {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(220, 220, 220, 0.5);
    background-gradient-end: rgba(70, 70, 70, 0.5);
    box-shadow: inset 0px 0px 0px 1px rgba(100, 100, 100, 0.5);
}

.grouped-window-list-item-box:hover {
    box-shadow: inset 0px 0px 0px 1px rgba(120, 120, 120, 0.5);
}

.grouped-window-list-item-box:active {
    box-shadow: inset 0px 0px 0px 1px rgba(120, 120, 120, 0.3);
}

.grouped-window-list-item-demands-attention {
    background-gradient-start: rgba(255, 52, 52, 0.5);
    background-gradient-end: rgba(255, 144, 144, 0.5);
}

.grouped-window-list-preview {
    border: 1px solid rgba(50, 50, 50, 1);
    border-radius: 4px;
    background-color: rgba(63, 63, 63, 0.95);
    color: #fff;
    font-size: .95em;
    padding: 6px 12px 12px 12px;
    spacing: 0.5em;
}

.grouped-window-list-item-box .progress {
    border-radius: 4px 4px 0 0;
    background-gradient-direction: vertical;
    background-gradient-start: rgba(172, 205, 138, 0.5);
    background-gradient-end: rgba(172, 205, 138, 0.9);
}

.panel-top .grouped-window-list-item-box .progress {
    border-radius: 0 0 4px 4px;
}

.panel-left .grouped-window-list-item-box .progress {
    border-radius: 0 4px 4px 0;
}

.panel-right .grouped-window-list-item-box .progress {
    border-radius: 4px 0 0 4px;
}

.grouped-window-list-thumbnail-menu {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(70, 70, 70, 1);
    background-gradient-end: rgba(50, 50, 50, 1);
    border-radius: 8px;
    padding: 0px;
    font-size: .9em;
    color: white;
    box-shadow: 0px 0px 2px 2px rgba(0, 0, 0, 0.5);
}

.grouped-window-list-thumbnail-menu .item-box {
    padding: 10px;
    border: 1px solid rgba(0, 0, 0, 0);
    border-radius: 8px;
    spacing: 4px;
}

.grouped-window-list-thumbnail-menu .item-box:outlined {
    padding: 6px;
    border: 2px solid rgba(85, 85, 85, 1.0);
}

.grouped-window-list-thumbnail-menu .item-box:selected {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(90, 90, 90, 1);
    background-gradient-end: rgba(70, 70, 70, 1);
    border: 1px solid rgba(120, 120, 120, 1);
}

.grouped-window-list-thumbnail-menu .thumbnail {
    width: 256px;
}

.grouped-window-list-thumbnail-menu .separator {
    width: 1px;
    background: rgba(255, 255, 255, 0.33);
}

/* ===================================================================
 * Sound applet (sound@cinnamon.org/applet.js)
 * ===================================================================*/
.sound-player StButton {
    width: 22px;
    height: 22px;
    padding: 5px;
    color: #bbb;
}

.sound-player StButton:small {
    border: 1px solid transparent;
    border-radius: 3px;
    width: 16px;
    height: 16px;
    color: rgb(200, 200, 200);
}

.sound-player StButton:hover,
.sound-player StButton:active {
    color: #fff;
}

.sound-player StButton:small:hover {
    color: rgb(255, 255, 255);
    border-image: url("button-assets/button-hover.png") 4;
}

.sound-player StButton:small:active {
    color: rgb(255, 255, 255);
    border-image: url("button-assets/button-pressed.png") 4;
}

.sound-player .slider {
    height: 0.5em;
    -slider-height: 0.5em;
    -slider-background-color: #7a7a7a;
    -slider-border-color: rgba(0, 0, 0, 0);
    -slider-active-background-color: #ffffff;
    -slider-active-border-color: rgba(0, 0, 0, 0);
    -slider-border-width: 0px;
    -slider-handle-radius: 0px;
}

.sound-player StBoxLayout {
    spacing: 0.5em;
}

.sound-player > StBoxLayout {
    padding: 0 16px 8px;
}

.sound-player-overlay {
    width: 300px;
    padding: 15px;
    spacing: 0.5em;
    background: rgba(0, 0, 0, 0.8);
    color: #FFF;
}

.sound-player-overlay StBoxLayout {
    padding-top: 2px;
}

.sound-player-generic-coverart {
    background: rgba(0, 0, 0, 0.2);
}

/* ===================================================================
 * Workspace Switcher applet (workspace-switcher@cinnamon.org/applet.js)
 * ===================================================================*/

/* Controls the styling when using the "Simple buttons" option */
.workspace-switcher {
    padding-left: 3px;
    padding-right: 3px;
}

.workspace-button {
    width: 20px;
    height: 14px;
    color: rgba(200, 200, 200, 1);
    border: 1px;
    border-color: rgba(200, 200, 200, 1);
    padding: 3px;
    padding-top: 0;
    padding-bottom: 3px;
    transition-duration: 300;
}

.workspace-button.vertical {
    height: 14px;
    width: 24px;
    padding: 0;
    padding-top: 1px;
    padding-bottom: 3px;
}

.workspace-button:outlined {
    background: rgba(200, 200, 200, 1);
    color: rgba(55, 55, 55, 1);
}

/* Controls the style when using the "Visual representation" option */
.workspace-graph {
    padding: 3px;
    spacing: 3px;
}

.workspace-graph .workspace {
    border: 1px solid #555;
    background-gradient-direction: vertical;
    background-gradient-start: #2a2a2a;
    background-gradient-end: #555;
    box-shadow: inset 0px 1px 3px rgba(0, 0, 0, 0.55);
}

.workspace-graph .workspace:active {
    border: 1px solid #ccc;
    background-gradient-direction: vertical;
    background-gradient-start: #111;
    background-gradient-end: #3d3d3d;
}

.workspace-graph .workspace .windows {
    -active-window-background: rgba(140, 140, 140, 1.0);
    -active-window-border: rgba(0, 0, 0, 0.7);
    -inactive-window-background: rgba(140, 140, 140, 1.0);
    -inactive-window-border: rgba(0, 0, 0, 0.7);
}

.workspace-graph .workspace:active .windows {
    -active-window-background: rgba(255, 255, 255, 1.0);
    -active-window-border: rgba(0, 0, 0, 0.9);
    -inactive-window-background: rgba(140, 140, 140, 1.0);
    -inactive-window-border: rgba(0, 0, 0, 0.7);
}

/* ===================================================================
 * Panel Launchers applet (panel-launchers@cinnamon.org/applet.js)
 * ===================================================================*/
.panel-launchers {
    spacing: 2px;
}

.panel-launchers .launcher {
    padding-left: 1px;
    padding-right: 1px;
    border: 0 solid transparent;
    border-bottom-width: 1px;
}

.panel-launchers .launcher:hover {
    background-gradient-direction: vertical;
    background-gradient-start: rgba(255, 255, 255, 0.0);
    background-gradient-end: rgba(255, 255, 255, 0.2);
    border-color: rgba(255, 255, 255, 0.5);
}

/* ===================================================================
 * Applets (applet.js)
 * ===================================================================*/
.applet-separator {
    padding: 5px 4px;
}

.applet-separator-line {
    width: 2px;
    background: rgba(255, 255, 255, 0.5);
}

.applet-box {
    padding-left: 3px;
    padding-right: 3px;
    color: #ccc;
    spacing: 3px;
    text-shadow: black 0px 0px 2px;
    text-align: center;
}

.applet-box.vertical {
    padding: 3px;
}

.applet-box:checked,
.applet-box:hover {
    color: #fff;
}

.applet-box:highlight {
    background-color: #aa5555;
}

.applet-label {
    font-weight: bold;
    color: #ccc;
}

.applet-label:hover,
.applet-label:checked,
.applet-box:checked .applet-label,
.applet-box:hover .applet-label {
    color: #fff;
    text-shadow: white 0px 0px 5px;
}

.applet-icon {
    color: #ccc;
    icon-size: 22px;
}

.applet-icon:hover,
.applet-icon:checked,
.applet-box:hover .applet-icon,
.applet-box:checked .applet-icon {
    color: #fff;
    icon-shadow: white 0px 0px 3px;
}

/* ===================================================================
 * Workspace OSD (windowManager.js)
 * ===================================================================*/
.workspace-osd {
    color: #ffffff;
    text-shadow: black 5px 5px 5px;
    font-weight: bold;
    font-size: 4.8em;
}

.expo-workspaces-name-entry {
    padding: 5px;
    border-radius: 4px;
    color: rgb(128, 128, 128);
    border: 2px solid rgb(136, 138, 133);
    background-gradient-start: rgb(200, 200, 200);
    background-gradient-end: white;
    background-gradient-direction: vertical;
    selected-color: black;
    caret-color: rgb(128, 128, 128);
    caret-size: 1px;
    width: 250px;
    height: 1.5em;
    box-shadow: inset 0px 2px 4px rgba(0, 0, 0, 0.6);
    text-align: center;
}

.expo-workspaces-name-entry#selected {
    background-gradient-start: rgb(128, 128, 128);
    background-gradient-end: black;
    color: rgb(200, 200, 200);
}

.expo-workspaces-name-entry:focus {
    color: rgb(64, 64, 64);
    font-weight: bold;
    transition-duration: 300;
}

/* ===================================================================
 * Notification applet (notifications@cinnamon.org/applet.js)
 * ===================================================================*/
.notification-applet-padding {
    padding: .5em 1em;
}

.notification-applet-container {
    max-height: 100px;
}

/* Check Boxes */
.check-box CinnamonGenericContainer {
    spacing: .2em;
}

.check-box StBin,
.check-box:focus StBin {
    width: 16px;
    height: 16px;
    background-image: url("checkbox-off.svg");
}

.check-box:checked StBin,
.check-box:focus:checked StBin {
    background-image: url("checkbox.svg");
}

.check-box StLabel {
    font-weight: normal;
}

.radiobutton CinnamonGenericContainer {
    spacing: .2em;
    height: 18px;
    padding-top: 2px;
}

.radiobutton StBin,
.radiobutton:focus StBin {
    width: 16px;
    height: 16px;
    background-image: url("radiobutton-off.svg");
    border-radius: 15px;
}

.radiobutton:checked StBin,
.radiobutton:focus:checked StBin {
    background-image: url("radiobutton.svg");
}

.radiobutton StLabel {
    padding-top: 4px;
    font-size: 0.9em;
    box-shadow: none;
}

.flashspot {
    background-color: white;
}

/* ===================================================================
 * Snap/Tile Chrome (windowManager.js)
 * ===================================================================*/
.tile-preview,
.tile-hud {
    background-color: rgba(63, 63, 63, 0.7);
    border: 1px solid rgba(120, 120, 120, 0.9);
}

.tile-preview.snap,
.tile-hud.snap {
    background-color: rgba(134, 170, 134, 0.5);
    border: 1px solid rgba(85, 85, 85, 0.8);
}

.tile-hud:top {
    border-top-width: 0px;
    border-radius: 0px 0px 8px 8px;
}

.tile-hud:bottom {
    border-bottom-width: 0px;
    border-radius: 8px 8px 0px 0px;
}

.tile-hud:left {
    border-left-width: 0px;
    border-radius: 0px 8px 8px 0px;
}

.tile-hud:right {
    border-right-width: 0px;
    border-radius: 8px 0px 0px 8px;
}

.tile-hud:top-left {
    border-top-width: 0px;
    border-left-width: 0px;
    border-radius: 0px 0px 8px 0px;
}

.tile-hud:top-right {
    border-top-width: 0px;
    border-right-width: 0px;
    border-radius: 0px 0px 0px 8px;
}

.tile-hud:bottom-left {
    border-bottom-width: 0px;
    border-left-width: 0px;
    border-radius: 0px 8px 0px 0px;
}

.tile-hud:bottom-right {
    border-bottom-width: 0px;
    border-right-width: 0px;
    border-radius: 8px 0px 0px 0px;
}
