style "terminal_screen"
{
    text[NORMAL] = "#ffffff"
    base[NORMAL] = "#3f3f3f"

    TerminalScreen::background-darkness = 0.95
}

widget "*TerminalWindow.*.TerminalScreen*" style "terminal_screen"
