style "treeview-header"
{
    GtkWidget::interior-focus = 1
    
    xthickness = 2
    ythickness = 2
    
    bg[NORMAL] = shade (1.06, @bg_color)
    bg[PRELIGHT] = shade (1.1, @bg_color)
    bg[ACTIVE] = shade (0.9, @bg_color)
    
    engine "murrine"
    {
        arrowstyle = 1
        border_shades = {0.85, 0.75}
        contrast = 0.4
        focusstyle = 0
        highlight_shade = 1.0
        lightborder_shade = 1.2
        lightborderstyle = 1
        gradient_shades = {1.1, 1.1, 0.94, 0.94}
        textstyle = 1
    }
}

style "treeview"
{
    xthickness = 2
    ythickness = 2
    
    base[NORMAL] = @base_color
    
    engine "pixmap" 
    {
        image
        {
            function = FLAT_BOX
            recolorable = TRUE
            state = NORMAL
            file = "images/other/null.png"
            stretch = TRUE
        }
        image
        {
            function = FLAT_BOX
            recolorable = TRUE
            state = SELECTED
            file = "images/treeview/row-selected.svg"
            border = {2, 2, 2, 2}
            stretch = TRUE
        }
        image
        {
            function = FOCUS
            file = "images/other/null.png"
        }
        
        # Treeview Progress Bar
        
        image
        {
            function = BOX
            state = NORMAL
            file = "images/treeview/progress-trough.svg"
            border = {2, 2, 2, 2}
            shadow = IN
        }
        image
        {
            function = BOX
            state = SELECTED
            file = "images/treeview/progress-bar.svg"
            stretch = TRUE
            border = {2, 2, 2, 2}
            orientation = HORIZONTAL
            shadow = OUT
            detail = "bar"
        }
        
        # Check
        
        image
        {
            function = CHECK
            state = NORMAL
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = PRELIGHT
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = ACTIVE
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = SELECTED
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            state = INSENSITIVE
            shadow = OUT
            overlay_file = "images/check-radio/checkbox-unchecked-insensitive.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = NORMAL
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = PRELIGHT
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = ACTIVE
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = SELECTED
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = CHECK
            recolorable = TRUE
            state = INSENSITIVE
            shadow = IN
            overlay_file = "images/check-radio/checkbox-checked-insensitive.svg"
            overlay_stretch = FALSE
        }
        
        # Radio
        
        image
        {
            function = OPTION
            state = NORMAL
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = PRELIGHT
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = ACTIVE
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = SELECTED
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            state = INSENSITIVE
            shadow = OUT
            overlay_file = "images/check-radio/radio-unselected-insensitive.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = NORMAL
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = PRELIGHT
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = ACTIVE
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = SELECTED
            shadow = IN
            overlay_file = "images/check-radio/radio-selected.svg"
            overlay_stretch = FALSE
        }
        image
        {
            function = OPTION
            recolorable = TRUE
            state = INSENSITIVE
            shadow = IN
            overlay_file = "images/check-radio/radio-selected-insensitive.svg"
            overlay_stretch = FALSE
        }
    }
}

style "iconview"
{
    engine "pixmap"
    {
        image
        {
            function = FLAT_BOX
            recolorable = TRUE
            file = "images/treeview/iconview-selected.svg"
            border = {3, 3, 3, 3}
            stretch = TRUE
        }
    }
}
